@@ -658,7 +658,9 @@ void AlnSinkWrap::finishRead(
 	const PerReadMetrics& prm,      // per-read metrics
 	const Scoring& sc,              // scoring scheme
 	bool suppressSeedSummary,       // = true
-	bool suppressAlignments)        // = false
+	bool suppressAlignments,        // = false
+	bool scUnMapped,                // = false
+	bool xeq)                       // = false
 {
 	obuf_.clear();
 	OutputQueueMark qqm(g_.outq(), obuf_, rdid_, threadid_);
@@ -715,16 +717,52 @@ void AlnSinkWrap::finishRead(
 				rd1_, rd2_, &rs1_, &rs2_, &rs1u_, &rs2u_,
 				exhaust1, exhaust2, -1, -1);
 			// Sort by score then pick from low to high
-			AlnScore bestUnchosen1, bestUnchosen2, bestUnchosenC;
+			AlnScore bestUScore, bestP1Score, bestP2Score, bestCScore;
+			AlnScore bestUDist, bestP1Dist, bestP2Dist, bestCDist;
+			AlnScore bestUnchosenUScore, bestUnchosenP1Score, bestUnchosenP2Score, bestUnchosenCScore;
+			AlnScore bestUnchosenUDist, bestUnchosenP1Dist, bestUnchosenP2Dist, bestUnchosenCDist;
+			// TODO: should probably package these variables up so it's not
+			// such a pain to pass them around
 			size_t off = selectByScore(
 				&rs1_, &rs2_,
 				nconcord, select1_,
 				&rs1u_, &rs2u_,
-				bestUnchosen1, bestUnchosen2, bestUnchosenC,
+				bestUScore,
+				bestUDist,
+				bestP1Score,
+				bestP1Dist,
+				bestP2Score,
+				bestP2Dist,
+				bestCScore,
+				bestCDist,
+				bestUnchosenUScore,
+				bestUnchosenUDist,
+				bestUnchosenP1Score,
+				bestUnchosenP1Dist,
+				bestUnchosenP2Score,
+				bestUnchosenP2Dist,
+				bestUnchosenCScore,
+				bestUnchosenCDist,
 				rnd);
-			concordSumm.setUnchosen(bestUnchosen1, bestUnchosen2, bestUnchosenC);
-			assert(concordSumm.best(true).valid());
-			assert(concordSumm.best(false).valid());
+			concordSumm.setBest(
+				bestUScore,
+				bestUDist,
+				bestP1Score,
+				bestP1Dist,
+				bestP2Score,
+				bestP2Dist,
+				bestCScore,
+				bestCDist,
+				bestUnchosenUScore,
+				bestUnchosenUDist,
+				bestUnchosenP1Score,
+				bestUnchosenP1Dist,
+				bestUnchosenP2Score,
+				bestUnchosenP2Dist,
+				bestUnchosenCScore,
+				bestUnchosenCDist);
+			assert(concordSumm.bestScore(true).valid());
+			assert(concordSumm.bestScore(false).valid());
 			assert_lt(off, rs1_.size());
 			const AlnRes *rs1 = &rs1_[off];
 			const AlnRes *rs2 = &rs2_[off];
@@ -740,7 +778,9 @@ void AlnSinkWrap::finishRead(
 				st_.params().mixed,
 				true,       // primary
 				true,       // opp aligned
-				rs2->fw()); // opp fw
+				rs2->fw(),  // opp fw
+				scUnMapped,
+				xeq);
 			AlnFlags flags2(
 				ALN_FLAG_PAIR_CONCORD_MATE2,
 				st_.params().mhitsSet(),
@@ -753,7 +793,9 @@ void AlnSinkWrap::finishRead(
 				st_.params().mixed,
 				false,      // primary
 				true,       // opp aligned
-				rs1->fw()); // opp fw
+				rs1->fw(),  // opp fw
+				scUnMapped,
+				xeq);
 			// Issue: we only set the flags once, but some of the flags might
 			// vary from pair to pair among the pairs we're reporting.  For
 			// instance, whether the a given mate aligns to the forward strand.
@@ -802,7 +844,7 @@ void AlnSinkWrap::finishRead(
 			//g_.outq().finishRead(obuf_, rdid_, threadid_);
 			return;
 		}
-		// Report concordant paired-end alignments if possible
+		// Report disconcordant paired-end alignments if possible
 		else if(ndiscord > 0) {
 			ASSERT_ONLY(bool ret =) prepareDiscordants();
 			assert(ret);
@@ -825,7 +867,9 @@ void AlnSinkWrap::finishRead(
 				st_.params().mixed,
 				true,       // primary
 				true,       // opp aligned
-				rs2->fw()); // opp fw
+				rs2->fw(),  // opp fw
+				scUnMapped,
+				xeq);
 			AlnFlags flags2(
 				ALN_FLAG_PAIR_DISCORD_MATE2,
 				st_.params().mhitsSet(),
@@ -838,7 +882,9 @@ void AlnSinkWrap::finishRead(
 				st_.params().mixed,
 				false,      // primary
 				true,       // opp aligned
-				rs1->fw()); // opp fw
+				rs1->fw(),  // opp fw
+				scUnMapped,
+				xeq);
 			SeedAlSumm ssm1, ssm2;
 			sr1->toSeedAlSumm(ssm1);
 			sr2->toSeedAlSumm(ssm2);
@@ -848,13 +894,48 @@ void AlnSinkWrap::finishRead(
 				assert(rs1_[i].isFraglenSet() == rs2_[i].isFraglenSet());
 				assert(!rs1_[i].isFraglenSet() || abs(rs1_[i].fragmentLength()) == abs(rs2_[i].fragmentLength()));
 			}
-			AlnScore bestUnchosen1, bestUnchosen2, bestUnchosenC;
+			AlnScore bestUScore, bestP1Score, bestP2Score, bestCScore;
+			AlnScore bestUDist, bestP1Dist, bestP2Dist, bestCDist;
+			AlnScore bestUnchosenUScore, bestUnchosenP1Score, bestUnchosenP2Score, bestUnchosenCScore;
+			AlnScore bestUnchosenUDist, bestUnchosenP1Dist, bestUnchosenP2Dist, bestUnchosenCDist;
 			ASSERT_ONLY(size_t off =) selectByScore(
 				&rs1_, &rs2_,
 				ndiscord, select1_,
 				&rs1u_, &rs2u_,
-				bestUnchosen1, bestUnchosen2, bestUnchosenC,
+				bestUScore,
+				bestUDist,
+				bestP1Score,
+				bestP1Dist,
+				bestP2Score,
+				bestP2Dist,
+				bestCScore,
+				bestCDist,
+				bestUnchosenUScore,
+				bestUnchosenUDist,
+				bestUnchosenP1Score,
+				bestUnchosenP1Dist,
+				bestUnchosenP2Score,
+				bestUnchosenP2Dist,
+				bestUnchosenCScore,
+				bestUnchosenCDist,
 				rnd);
+			discordSumm.setBest(
+				bestUScore,
+				bestUDist,
+				bestP1Score,
+				bestP1Dist,
+				bestP2Score,
+				bestP2Dist,
+				bestCScore,
+				bestCDist,
+				bestUnchosenUScore,
+				bestUnchosenUDist,
+				bestUnchosenP1Score,
+				bestUnchosenP1Dist,
+				bestUnchosenP2Score,
+				bestUnchosenP2Dist,
+				bestUnchosenCScore,
+				bestUnchosenCDist);
 			assert_eq(0, off);
 			assert(!select1_.empty());
 			g_.reportHits(
@@ -984,9 +1065,46 @@ void AlnSinkWrap::finishRead(
 				rd1_, NULL, NULL, NULL, &rs1u_, NULL,
 				exhaust1, exhaust2, -1, -1);
 			// Sort by score then pick from low to high
-			AlnScore tmp;
+			AlnScore bestUScore, bestP1Score, bestP2Score, bestCScore;
+			AlnScore bestUDist, bestP1Dist, bestP2Dist, bestCDist;
+			AlnScore bestUnchosenUScore, bestUnchosenP1Score, bestUnchosenP2Score, bestUnchosenCScore;
+			AlnScore bestUnchosenUDist, bestUnchosenP1Dist, bestUnchosenP2Dist, bestUnchosenCDist;
 			size_t off = selectByScore(
-				&rs1u_, NULL, nunpair1, select1_, NULL, NULL, tmp, tmp, tmp, rnd);
+				&rs1u_, NULL, nunpair1, select1_, NULL, NULL,
+				bestUScore,
+				bestUDist,
+				bestP1Score,
+				bestP1Dist,
+				bestP2Score,
+				bestP2Dist,
+				bestCScore,
+				bestCDist,
+				bestUnchosenUScore,
+				bestUnchosenUDist,
+				bestUnchosenP1Score,
+				bestUnchosenP1Dist,
+				bestUnchosenP2Score,
+				bestUnchosenP2Dist,
+				bestUnchosenCScore,
+				bestUnchosenCDist,
+				rnd);
+			summ1.setBest(
+				bestUScore,
+				bestUDist,
+				bestP1Score,
+				bestP1Dist,
+				bestP2Score,
+				bestP2Dist,
+				bestCScore,
+				bestCDist,
+				bestUnchosenUScore,
+				bestUnchosenUDist,
+				bestUnchosenP1Score,
+				bestUnchosenP1Dist,
+				bestUnchosenP2Score,
+				bestUnchosenP2Dist,
+				bestUnchosenCScore,
+				bestUnchosenCDist);
 			repRs1 = &rs1u_[off];
 		} else if(rd1_ != NULL) {
 			// Mate 1 failed to align - don't do anything yet.  First we want
@@ -1000,9 +1118,46 @@ void AlnSinkWrap::finishRead(
 				NULL, rd2_, NULL, NULL, NULL, &rs2u_,
 				exhaust1, exhaust2, -1, -1);
 			// Sort by score then pick from low to high
-			AlnScore tmp;
+			AlnScore bestUScore, bestP1Score, bestP2Score, bestCScore;
+			AlnScore bestUDist, bestP1Dist, bestP2Dist, bestCDist;
+			AlnScore bestUnchosenUScore, bestUnchosenP1Score, bestUnchosenP2Score, bestUnchosenCScore;
+			AlnScore bestUnchosenUDist, bestUnchosenP1Dist, bestUnchosenP2Dist, bestUnchosenCDist;
 			size_t off = selectByScore(
-				&rs2u_, NULL, nunpair2, select2_, NULL, NULL, tmp, tmp, tmp, rnd);
+				&rs2u_, NULL, nunpair2, select2_, NULL, NULL,
+				bestUScore,
+				bestUDist,
+				bestP1Score,
+				bestP1Dist,
+				bestP2Score,
+				bestP2Dist,
+				bestCScore,
+				bestCDist,
+				bestUnchosenUScore,
+				bestUnchosenUDist,
+				bestUnchosenP1Score,
+				bestUnchosenP1Dist,
+				bestUnchosenP2Score,
+				bestUnchosenP2Dist,
+				bestUnchosenCScore,
+				bestUnchosenCDist,
+				rnd);
+			summ2.setBest(
+				bestUScore,
+				bestUDist,
+				bestP1Score,
+				bestP1Dist,
+				bestP2Score,
+				bestP2Dist,
+				bestCScore,
+				bestCDist,
+				bestUnchosenUScore,
+				bestUnchosenUDist,
+				bestUnchosenP1Score,
+				bestUnchosenP1Dist,
+				bestUnchosenP2Score,
+				bestUnchosenP2Dist,
+				bestUnchosenCScore,
+				bestUnchosenCDist);
 			repRs2 = &rs2u_[off];
 		} else if(rd2_ != NULL) {
 			// Mate 2 failed to align - don't do anything yet.  First we want
@@ -1029,7 +1184,9 @@ void AlnSinkWrap::finishRead(
 				st_.params().mixed,
 				true,   // primary
 				repRs2 != NULL,                    // opp aligned
-				repRs2 == NULL || repRs2->fw());   // opp fw
+				repRs2 == NULL || repRs2->fw(),    // opp fw
+				scUnMapped,
+				xeq);
 			for(size_t i = 0; i < rs1u_.size(); i++) {
 				rs1u_[i].setMateParams(ALN_RES_TYPE_UNPAIRED_MATE1, NULL, flags1);
 			}
@@ -1051,7 +1208,9 @@ void AlnSinkWrap::finishRead(
 				st_.params().mixed,
 				true,   // primary
 				repRs1 != NULL,                  // opp aligned
-				repRs1 == NULL || repRs1->fw()); // opp fw
+				repRs1 == NULL || repRs1->fw(),  // opp fw
+				scUnMapped,
+				xeq);
 			for(size_t i = 0; i < rs2u_.size(); i++) {
 				rs2u_[i].setMateParams(ALN_RES_TYPE_UNPAIRED_MATE2, NULL, flags2);
 			}
@@ -1150,7 +1309,9 @@ void AlnSinkWrap::finishRead(
 				st_.params().mixed,
 				true,           // primary
 				repRs2 != NULL, // opp aligned
-				(repRs2 != NULL) ? repRs2->fw() : false); // opp fw
+				(repRs2 != NULL) ? repRs2->fw() : false, // opp fw
+				scUnMapped,
+				xeq);
 			g_.reportUnaligned(
 				obuf_,      // string to write output to
 				staln_,
@@ -1196,7 +1357,9 @@ void AlnSinkWrap::finishRead(
 				st_.params().mixed,
 				true,           // primary
 				repRs1 != NULL, // opp aligned
-				(repRs1 != NULL) ? repRs1->fw() : false); // opp fw
+				(repRs1 != NULL) ? repRs1->fw() : false, // opp fw
+				scUnMapped,
+				xeq);
 			g_.reportUnaligned(
 				obuf_,      // string to write output to
 				staln_,
@@ -1317,9 +1480,22 @@ size_t AlnSinkWrap::selectByScore(
 	EList<size_t>&       select, // prioritized list to put results in
 	const EList<AlnRes>* rs1u,   // alignments to select from (mate 1)
 	const EList<AlnRes>* rs2u,   // alignments to select from (mate 2, or NULL)
-	AlnScore&            bestUnchosen1,
-	AlnScore&            bestUnchosen2,
-	AlnScore&            bestUnchosenC,
+	AlnScore&            bestUScore,
+	AlnScore&            bestUDist,
+	AlnScore&            bestP1Score,
+	AlnScore&            bestP1Dist,
+	AlnScore&            bestP2Score,
+	AlnScore&            bestP2Dist,
+	AlnScore&            bestCScore,
+	AlnScore&            bestCDist,
+	AlnScore&            bestUnchosenUScore,
+	AlnScore&            bestUnchosenUDist,
+	AlnScore&            bestUnchosenP1Score,
+	AlnScore&            bestUnchosenP1Dist,
+	AlnScore&            bestUnchosenP2Score,
+	AlnScore&            bestUnchosenP2Dist,
+	AlnScore&            bestUnchosenCScore,
+	AlnScore&            bestUnchosenCDist,
 	RandomSource&        rnd)
 	const
 {
@@ -1327,11 +1503,26 @@ size_t AlnSinkWrap::selectByScore(
 	assert(repOk());
 	assert_gt(num, 0);
 	assert(rs1 != NULL);
-	
-	if(rs2 != NULL) {
-		assert(rs1u != NULL);
-		assert(rs2u != NULL);
-	}
+	assert(rs2 == NULL || rs1u != NULL);
+	assert(rs2 == NULL || rs2u != NULL);
+
+	bestUScore.invalidate();
+	bestUDist.invalidate();
+	bestUnchosenUScore.invalidate();
+	bestUnchosenUDist.invalidate();
+
+	bestCScore.invalidate();
+	bestP1Score.invalidate();
+	bestP2Score.invalidate();
+	bestCDist.invalidate();
+	bestP1Dist.invalidate();
+	bestP2Dist.invalidate();
+	bestUnchosenCScore.invalidate();
+	bestUnchosenP1Score.invalidate();
+	bestUnchosenP2Score.invalidate();
+	bestUnchosenCDist.invalidate();
+	bestUnchosenP1Dist.invalidate();
+	bestUnchosenP2Dist.invalidate();
 	
 	size_t sz = rs1->size(); // sz = # alignments found
 	assert_leq(num, sz);
@@ -1375,27 +1566,57 @@ size_t AlnSinkWrap::selectByScore(
 		buf.shufflePortion(buf.size() - streak, streak, rnd);
 	}
 	
+	// Copy the permutation into the 'select' list
 	for(size_t i = 0; i < num; i++) { select[i] = buf[i].second; }
 	
+	if(rs2 == NULL) {
+		bestUScore = bestUDist = (*rs1)[select[0]].score();
+	}
+	
+	// For paired-end read, find best alignment score among end
+	// alignments not chosen, for both ends
 	if(rs2 != NULL) {
+		bestCScore = bestCDist = (*rs1)[select[0]].score() + (*rs2)[select[0]].score();
+		bestP1Score = bestP1Dist = (*rs1)[select[0]].score();
+		bestP2Score = bestP2Dist = (*rs2)[select[0]].score();
 		for(size_t i = 0; i < rs1u->size(); i++) {
 			if((*rs1u)[i].refcoord() == (*rs1)[select[0]].refcoord()) {
 				continue;
 			}
-			if((*rs1u)[i].score() > bestUnchosen1) {
-				bestUnchosen1 = (*rs1u)[i].score();
+			if((*rs1u)[i].score() > bestUnchosenP1Score) {
+				bestUnchosenP1Score = (*rs1u)[i].score();
+			}
+			if((*rs1u)[i].score().basesAligned() > bestUnchosenP1Dist.basesAligned()) {
+				bestUnchosenP1Dist = (*rs1u)[i].score();
 			}
 		}
 		for(size_t i = 0; i < rs2u->size(); i++) {
 			if((*rs2u)[i].refcoord() == (*rs2)[select[0]].refcoord()) {
 				continue;
 			}
-			if((*rs2u)[i].score() > bestUnchosen2) {
-				bestUnchosen2 = (*rs2u)[i].score();
+			if((*rs2u)[i].score() > bestUnchosenP2Score) {
+				bestUnchosenP2Score = (*rs2u)[i].score();
+			}
+			if((*rs2u)[i].score().basesAligned() > bestUnchosenP2Dist.basesAligned()) {
+				bestUnchosenP2Dist = (*rs2u)[i].score();
 			}
 		}
 		if(buf.size() > 1) {
-			bestUnchosenC = buf[1].first;
+			bestUnchosenCScore = buf[1].first;
+			for(size_t i = 1; i < buf.size(); i++) {
+				AlnScore dist = (*rs1)[buf[i].second].score() +
+				                (*rs2)[buf[i].second].score();
+				if(dist.basesAligned() > bestUnchosenCDist.basesAligned()) {
+					bestUnchosenCDist = dist;
+				}
+			}
+		}
+	} else if(buf.size() > 1) {
+		bestUnchosenUScore = (*rs1)[buf[1].second].score();
+		for(size_t i = 1; i < buf.size(); i++) {
+			if((*rs1)[buf[1].second].score().basesAligned() > bestUnchosenUDist.basesAligned()) {
+				bestUnchosenUDist = (*rs1)[buf[1].second].score();
+			}
 		}
 	}
 	
@@ -1707,8 +1928,8 @@ void AlnSinkSam::appendMate(
 		}
 		fl |= (flags.readMate1() ?
 			SAM_FLAG_FIRST_IN_PAIR : SAM_FLAG_SECOND_IN_PAIR);
-		if(flags.mateAligned() && rso != NULL) {
-			if(!rso->fw()) {
+		if(flags.mateAligned()) {
+			if(!flags.isOppFw()) {
 				fl |= SAM_FLAG_MATE_STRAND;
 			}
 		}
@@ -1776,7 +1997,7 @@ void AlnSinkSam::appendMate(
 	}
 	// CIGAR
 	if(rs != NULL) {
-		staln.buildCigar(false);
+		staln.buildCigar(flags.xeq());
 		staln.writeCigar(&o, NULL);
 		o.append('\t');
 	} else {
@@ -1889,6 +2110,7 @@ void AlnSinkSam::appendMate(
 			prm,         // per-read metrics
 			sc);         // scoring scheme
 	}
+	samc_.printPreservedOptFlags(o, rd);
 	o.append('\n');
 }
 
