@@ -121,8 +121,8 @@ struct ReportingMetrics {
 	 * into this object.  This is the only safe way to update a
 	 * ReportingMetrics shared by multiple threads.
 	 */
-	void merge(const ReportingMetrics& met, bool getLock = false) {
-        ThreadSafe ts(&mutex_m, getLock);
+	void merge(const ReportingMetrics& met) {
+		ThreadSafe ts(mutex_m);
 		nread         += met.nread;
 
 		npaired       += met.npaired;
@@ -609,13 +609,6 @@ public:
 	 */
 	virtual ~AlnSink() { }
 
-	/**
-	 * Called when the AlnSink is wrapped by a new AlnSinkWrap.  This helps us
-	 * keep track of whether the main lock or any of the per-stream locks will
-	 * be contended by multiple threads.
-	 */
-	void addWrapper() { numWrappers_++; }
-
 	/**
 	 * Append a single hit to the given output stream.  If
 	 * synchronization is required, append() assumes the caller has
@@ -854,8 +847,8 @@ public:
 	/**
 	 * Merge given metrics in with ours by summing all individual metrics.
 	 */
-	void mergeMetrics(const ReportingMetrics& met, bool getLock = true) {
-		met_.merge(met, getLock);
+	void mergeMetrics(const ReportingMetrics& met) {
+		met_.merge(met);
 	}
 
 	/**
@@ -868,7 +861,6 @@ public:
 protected:
 
 	OutputQueue&       oq_;           // output queue
-	int                numWrappers_;  // # threads owning a wrapper for this HitSink
 	const StrList&     refnames_;     // reference names
 	bool               quiet_;        // true -> don't print alignment stats at the end
 	ReportingMetrics   met_;          // global repository of reporting metrics
@@ -1037,7 +1029,9 @@ public:
 		const PerReadMetrics& prm,      // per-read metrics
 		const Scoring& sc,              // scoring scheme
 		bool suppressSeedSummary = true,
-		bool suppressAlignments = false);
+		bool suppressAlignments = false,
+		bool scUnMapped = false,
+		bool xeq = false);
 	
 	/**
 	 * Called by the aligner when a new unpaired or paired alignment is
@@ -1240,9 +1234,22 @@ protected:
 		EList<size_t>&       select, // prioritized list to put results in
 		const EList<AlnRes>* rs1u,   // alignments to select from (mate 1)
 		const EList<AlnRes>* rs2u,   // alignments to select from (mate 2, or NULL)
-		AlnScore&            bestUnchosen1,
-		AlnScore&            bestUnchosen2,
-		AlnScore&            bestUnchosenC,
+		AlnScore&            bestUScore,
+		AlnScore&            bestUDist,
+		AlnScore&            bestP1Score,
+		AlnScore&            bestP1Dist,
+		AlnScore&            bestP2Score,
+		AlnScore&            bestP2Dist,
+		AlnScore&            bestCScore,
+		AlnScore&            bestCDist,
+		AlnScore&            bestUnchosenUScore,
+		AlnScore&            bestUnchosenUDist,
+		AlnScore&            bestUnchosenP1Score,
+		AlnScore&            bestUnchosenP1Dist,
+		AlnScore&            bestUnchosenP2Score,
+		AlnScore&            bestUnchosenP2Dist,
+		AlnScore&            bestUnchosenCScore,
+		AlnScore&            bestUnchosenCDist,
 		RandomSource&        rnd)
 		const;
 
