@@ -20,21 +20,17 @@
 #ifndef FILEBUF_H_
 #define FILEBUF_H_
 
-#include <errno.h>
-#include <fcntl.h>
-#include <fstream>
 #include <iostream>
-#include <stdexcept>
-#include <stdint.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include <fstream>
 #include <string>
-#include <unistd.h>
-#include <zlib.h>
-
-#include "alphabet.h"
+#include <stdio.h>
+#include <string.h>
+#include <stdint.h>
+#include <stdexcept>
 #include "assert_helpers.h"
+#include <errno.h>
+#include <stdlib.h>
+#include <zlib.h>
 
 /**
  * Simple, fast helper for determining if a character is a newline.
@@ -91,16 +87,11 @@ public:
 		assert(_ins != NULL);
 	}
 
-
-	~FileBuf() {
-		close();
-	}
-
 	/**
 	 * Return true iff there is a stream ready to read.
 	 */
 	bool isOpen() {
-		return _in != NULL || _zIn != NULL || _inf != NULL || _ins != NULL;
+		return _in != NULL || _inf != NULL || _ins != NULL;
 	}
 
 	/**
@@ -357,7 +348,7 @@ public:
 		assert_neq(c, '\n');
 		return c;
 	}
-
+	
 	/**
 	 * Parse a FASTA record.  Append name characters to 'name' and and append
 	 * all sequence characters to 'seq'.  If gotCaret is true, assuming the
@@ -393,7 +384,7 @@ public:
 			// if we see caret or EOF, break
 			if(c == '>' || c == -1) break;
 			// append and continue
-			seq[seqcur++] = asc2dna[c];
+			seq[seqcur++] = c;
 			get(); c = peek();
 		}
 	}
@@ -467,39 +458,6 @@ public:
 		return _lastn_cur;
 	}
 
-	static bool isGzippedFile(const char *filename) {
-		if (filename == NULL) {
-			return false;
-		}
-
-		int fd = open(filename, O_RDONLY);
-		if (fd == -1) {
-			std::cerr << "Unable to open " << filename << std::endl;
-			throw 1;
-		}
-
-		uint8_t byte1, byte2;
-
-		ssize_t r1 = read(fd, &byte1, sizeof(uint8_t));
-		ssize_t r2 = read(fd, &byte2, sizeof(uint8_t));
-
-		if (::close(fd) == -1) {
-			std::cerr << "Unable to close " << filename << std::endl;
-			throw 1;
-		}
-
-		if (r1 == 0 || r2 == 0) {
-                        std::cerr << "Unable to read file magic number" << std::endl;
-                        return false;
-                }
-
-		if (byte1 == 0x1f && byte2 == 0x8b) {
-			return true;
-		}
-
-		return false;
-	}
-
 private:
 
 	void init() {
@@ -636,7 +594,7 @@ public:
 	OutFileBuf() : name_("cout"), cur_(0), closed_(false) {
 		out_ = stdout;
 	}
-
+	
 	/**
 	 * Close buffer when object is destroyed.
 	 */
