@@ -447,13 +447,13 @@ int BitPairReference::getStretch(
 	uint64_t off = 0;
 	int64_t offset = 4;
 	bool firstStretch = true;
-	bool binarySearched = false;
+	ASSERT_ONLY(bool binarySearched = false);
 	uint64_t left  = reci;
 	uint64_t right = recf;
 	uint64_t mid   = 0;
 	// For all records pertaining to the target reference sequence...
 	for(uint64_t i = reci; i < recf; i++) {
-		uint64_t origBufOff = bufOff;
+		ASSERT_ONLY(uint64_t origBufOff = bufOff);
 		assert_geq(toff, off);
 		if (firstStretch && recf > reci + 16){
 			// binary search finds smallest i s.t. toff >= cumRefOff_[i]
@@ -466,10 +466,10 @@ int BitPairReference::getStretch(
 			}
 			off = cumRefOff_[left];
 			bufOff = cumUnambig_[left];
-			origBufOff = bufOff;
+			ASSERT_ONLY(origBufOff = bufOff);
 			i = left;
 			assert(cumRefOff_[i+1] == 0 || cumRefOff_[i+1] > toff);
-			binarySearched = true;
+			ASSERT_ONLY(binarySearched = true);
 		}
 		off += recs_[i].off; // skip Ns at beginning of stretch
 		assert_gt(count, 0);
