@@ -501,7 +501,7 @@ inline const char * sstr_to_cstr<std::basic_string<char> >(
  */
 template<typename T>
 class SString {
-
+                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                
 public:
 
 	explicit SString() :
@@ -519,7 +519,7 @@ public:
 	}
 
 	/**
-	 * Create an SString from another SString.
+	 * Create an SStringExpandable from another SStringExpandable.
 	 */
 	SString(const SString<T>& o) :
 		cs_(NULL),
@@ -530,7 +530,7 @@ public:
 	}
 
 	/**
-	 * Create an SString from a std::basic_string of the
+	 * Create an SStringExpandable from a std::basic_string of the
 	 * appropriate type.
 	 */
 	explicit SString(const std::basic_string<T>& str) :
@@ -542,7 +542,7 @@ public:
 	}
 
 	/**
-	 * Create an SString from an array and size.
+	 * Create an SStringExpandable from an array and size.
 	 */
 	explicit SString(const T* b, size_t sz) :
 		cs_(NULL),
@@ -553,7 +553,7 @@ public:
 	}
 
 	/**
-	 * Create an SString from a zero-terminated array.
+	 * Create an SStringExpandable from a zero-terminated array.
 	 */
 	explicit SString(const T* b) :
 		cs_(NULL),
@@ -907,7 +907,7 @@ public:
 	}
 
 	/**
-	 * Create an S2bDnaString from a std::basic_string of the
+	 * Create an SStringExpandable from a std::basic_string of the
 	 * appropriate type.
 	 */
 	explicit S2bDnaString(
@@ -930,7 +930,7 @@ public:
 	}
 
 	/**
-	 * Create an S2bDnaString from an array and size.
+	 * Create an SStringExpandable from an array and size.
 	 */
 	explicit S2bDnaString(
 		const char* b,
@@ -1735,9 +1735,9 @@ public:
 	}
 
 	/**
-	 * Assignment to other SStringFixed.
+	 * Assignment to other SStringExpandable.
 	 */
-	SStringExpandable<T,S>& operator=(const SStringExpandable<T,S>& o) {
+	SStringExpandable<T,S,M,I>& operator=(const SStringExpandable<T,S,M,I>& o) {
 		install(o.cs_, o.len_);
 		return *this;
 	}
@@ -2075,15 +2075,6 @@ public:
 	 */
 	T* wbuf() { return cs_; }
 
-	void moveTo(SStringExpandable<T,S>& o) {
-		if (&o != this) {
-			o.sz_ = sz_; sz_ = 0;
-			o.cs_ = cs_; cs_ = NULL;
-			o.len_ = len_; len_ = 0;
-			o.printcs_ = printcs_; printcs_ = NULL;
-		}
-	}
-
 protected:
 	/**
 	 * Allocate new, bigger buffer and copy old contents into it.  If
@@ -2127,57 +2118,6 @@ protected:
 	size_t sz_;  // size capacity of cs_
 };
 
-	
-/**
- * Use stream operator to append char c.
- */
-template<typename T, int S, int M, int I>
-SStringExpandable<T, S, M, I>& operator<<(
-	SStringExpandable<T, S, M, I>& o,
-	char c)
-{
-	o.append(c);
-	return o;
-}
-
-/**
- * Use stream operator to append char c.
- */
-template<typename T, int S, int M, int I, typename A>
-SStringExpandable<T, S, M, I>& operator<<(
-	SStringExpandable<T, S, M, I>& o,
-	const A& i)
-{
-	char buf[1024];
-	itoa10<A>(static_cast<A>(i), buf);
-	o.append(buf);
-	return o;
-}
-
-/**
- * Use stream operator to append zero-terminated string.
- */
-template<typename T, int S, int M, int I>
-SStringExpandable<T, S, M, I>& operator<<(
-	SStringExpandable<T, S, M, I>& o,
-	const char *s)
-{
-	o.append(s);
-	return o;
-}
-
-/**
- * Use stream operator to append C++ string.
- */
-template<typename T, int S, int M, int I>
-SStringExpandable<T, S, M, I>& operator<<(
-	SStringExpandable<T, S, M, I>& o,
-	const std::string& s)
-{
-	o.append(s.c_str());
-	return o;
-}
-
 /**
  * Simple string class with in-object storage.
  *
